models = {
    "index": {
        0: 0,
        1: 1,
        2: 2,
        3: 3,
        4: 4,
        5: 5,
        6: 6,
        7: 8,
        8: 10,
        9: 11,
        10: 13,
        11: 14,
        12: 15,
        13: 16,
        14: 19,
        15: 21,
        16: 22,
        17: 23,
        18: 24,
        19: 25,
        20: 26,
        21: 29,
        22: 30,
        23: 32,
        24: 33,
        25: 34,
        26: 35,
        27: 37,
        28: 38,
        29: 39,
        30: 40,
        31: 41,
        32: 42,
        33: 43,
        34: 44,
        35: 45,
        36: 46,
        37: 47,
        38: 49,
        39: 50,
        40: 51,
        41: 52,
        42: 53,
        43: 54,
        44: 55,
        45: 56,
        46: 57,
        47: 58,
        48: 59,
        49: 60,
        50: 61,
        51: 63,
        52: 65,
        53: 67,
        54: 70,
        55: 71,
        56: 72,
        57: 73,
        58: 75,
        59: 80,
    },
    "NluRef": {
        0: "en.map_entity.umls_disease_syndrome_resolver",
        1: "en.answer_question.clinical_notes_onnx.pipeline",
        2: "en.classify.bert_sequence.vop_hcp_consult.pipeline",
        3: "en.resolve.cpt.augmented",
        4: "en.resolve.loinc.augmented",
        5: "en.summarize.clinical_guidelines_large.pipeline",
        6: "en.icd10cm_resolver.pipeline",
        7: "en.map_entity.umls_clinical_findings_resolver",
        8: "en.med_ner.nihss_pipeline",
        9: "en.resolve.icd9.pipeline",
        10: "en.map_entity.rxnorm_resolver.pipe",
        11: "en.resolve.HPO",
        12: "en.classify.bert_sequence.vop_drug_side_effect.pipeline",
        13: "en.map_entity.umls_drug_resolver",
        14: "en.summarize.clinical_laymen_onnx.pipeline",
        15: "en.explain_doc.era",
        16: "en.explain_doc.clinical_radiology.pipeline",
        17: "en.med_ner.pathogen.pipeline",
        18: "en.med_ner.vop_langtest",
        19: "en.resolve.icdo_augmented",
        20: "pt.deid.clinical",
        21: "ro.deid.clinical",
        22: "en.med_ner.sdoh_langtest.pipeline",
        23: "fr.deid_obfuscated",
        24: "en.summarize.clinical_questions.pipeline",
        25: "es.deid.clinical",
        26: "it.deid.clinical",
        27: "ar.deid.clinical",
        28: "en.de_identify.clinical_pipeline",
        29: "de.deid.clinical",
        30: "en.resolve.snomed.findings",
        31: "en.ner.oncology.pipeline",
        32: "pt.deid.clinical",
        33: "en.summarize.clinical_jsl_augmented.pipeline",
        34: "en.map_entity.umls_drug_resolver",
        35: "en.map_entity.icd10cm_to_snomed.pipe",
        36: "ro.deid.clinical",
        37: "en.map_entity.snomed_to_icd10cm.pipe",
        38: "fr.deid_obfuscated",
        39: "es.deid.clinical",
        40: "ar.deid.clinical",
        41: "de.deid.clinical",
        42: "it.deid.clinical",
        43: "en.de_identify.clinical_pipeline",
        44: "en.summarize.biomedical_pubmed.pipeline",
        45: "en.map_entity.snomed_to_icdo",
        46: "en.explain_doc.clinical_ade",
        47: "en.med_ner.risk_factors.pipeline",
        48: "en.map_entity.rxnorm_to_ndc.pipe",
        49: "en.summarize.radiology.pipeline",
        50: "en.med_ner.anatom.pipeline",
        51: "en.icd10cm.umls.mapping",
        52: "en.med_ner.living_species.pipeline",
        53: "en.icd10_icd9.mapping",
        54: "en.rxnorm.umls.mapping",
        55: "en.med_ner.bionlp.pipeline",
        56: "en.snomed.umls.mapping",
        57: "en.rxnorm.mes.mapping",
        58: "en.mesh.umls.mapping",
        59: "en.resolve.medication",
    },
    "Title": {
        0: "Extract Disease and Syndrom entities and their UMLS Codes",
        1: "Medical Question Answering (Open-Book on Clinical Notes)",
        2: "Detect Healthcare Professional Consult documents",
        3: "Extract procedures and measurements and their corresponding CPT codes",
        4: "Extract Laboratory Observations and the corresponding LOINC codes",
        5: "Guideline Summarizer for Asthma & Breast Cancer",
        6: "Extract Clinical Findings and the corresponding ICD10CM codes",
        7: "Extract Clinical Findings and their UMLS Codes",
        8: "Extract neurologic deficits related to Stroke Scale (NIHSS)",
        9: "Extract Clinical Findings and the corresponding ICD 9 codes",
        10: "Extract Drugs and the correspondingt RXNORM codes",
        11: "Extract phenotypic abnormalities and the coresponding HPO codes ",
        12: "Detect Drug Side Effect Narratives",
        13: "Extract  Drugs and Substances and their UMLS Codes",
        14: "Summarize Clinical Notes in Laymen Terms ",
        15: "Extract clinical events and find temporal relations (ERA)",
        16: "Extract findings in radiology reports",
        17: "Detect Pathogen, Medical Condition and Medicine",
        18: "Extract patient information from patient narratives",
        19: "Resolve Oncology terminology with ICD-O Taxonomy",
        20: "Clinical De-identification for Portuguese (Obfuscate)",
        21: "Clinical De-identification for Romanian (Obfuscate)",
        22: "Extract Social Determinants of Health",
        23: "Clinical De-identification for French (Obfuscate)",
        24: "Summarize Clinical Question Notes",
        25: "Clinical De-identification for Spanish (Obfuscate)",
        26: "Clinical De-identification for Italian (Obfuscate)",
        27: "Clinical De-identification for Arabic (Obfuscate)",
        28: "Clinical De-identification (Obfuscate)",
        29: "Clinical De-identification for German (Obfuscate)",
        30: "SNOMED Clinical Health Information Coder",
        31: "Extract oncological entities and relations",
        32: "Clinical De-identification for Portuguese (Mask)",
        33: "Clinical Text Summarization",
        34: "Extract Drugs and their UMLS Codes",
        35: "ICD-10-CM to SNOMED Code Mapper",
        36: "Clinical De-identification for Romanian (Mask)",
        37: "SNOMED to ICD-10-CM Code Mapper",
        38: "Clinical De-identification for French (Mask)",
        39: "Clinical De-identification for Spanish (Mask)",
        40: "Clinical De-identification for Arabic (Mask)",
        41: "Clinical De-identification for German (Mask)",
        42: "Clinical De-identification forItalian (Mask)",
        43: "Clinical De-identification (Mask)",
        44: "Summarize PubMed Research",
        45: "SNOMED Codes to ICDO Codes Mapper",
        46: "Extract Adverse Drug Events (ADE)",
        47: "Extract clinical risk factors",
        48: "RxNorm to NDC Code Converter",
        49: "Summarize Radiology Reports",
        50: "Extract Anatomical Structures",
        51: " ICD-10-CM to UMLS Code Mapper",
        52: "Extract Living Species",
        53: "ICD-10 to ICD-9 Code Converter",
        54: "RxNorm to UMLS Code Mapper",
        55: "Detect Cancer Genetics",
        56: "SNOMED to UMLS Code Mapper",
        57: "RxNorm to MeSH Code Mapper",
        58: "MeSH to UMLS Code Mapper",
        59: "Medication Coder",
    },
    "ReleaseID": {
        0: "0.9",
        1: "0.9",
        2: "0.9",
        3: "0.9",
        4: "0.9",
        5: "0.9",
        6: "0.9",
        7: "0.9",
        8: "0.9",
        9: "0.9",
        10: "0.9",
        11: "0.9",
        12: "0.9",
        13: "0.9",
        14: "0.9",
        15: "0.9",
        16: "0.9",
        17: "0.9",
        18: "0.9",
        19: "0.9",
        20: "0.9",
        21: "0.9",
        22: "0.9",
        23: "0.9",
        24: "0.9",
        25: "0.9",
        26: "0.9",
        27: "0.9",
        28: "0.9",
        29: "0.9",
        30: "0.9",
        31: "0.9",
        32: "0.9",
        33: "0.9",
        34: "0.9",
        35: "0.9",
        36: "0.9",
        37: "0.9",
        38: "0.9",
        39: "0.9",
        40: "0.9",
        41: "0.9",
        42: "0.9",
        43: "0.9",
        44: "0.9",
        45: "0.9",
        46: "0.9",
        47: "0.9",
        48: "0.9",
        49: "0.9",
        50: "0.9",
        51: "0.9",
        52: "0.9",
        53: "0.9",
        54: "0.9",
        55: "0.9",
        56: "0.9",
        57: "0.9",
        58: "0.9",
        59: "0.9",
    },
    "BaseModelPath": {
        0: "john_snow_labs_extract_disease_and_syndrom_entities_and_their_umls_codes.johnsnowlabs_folder.en_map_entity_umls_disease_syndrome_resolver",
        1: "john_snow_labs_medical_question_answering_open_book_on_clinical_notes.johnsnowlabs_folder.en_answer_question_clinical_notes_onnx_pipeline",
        2: "john_snow_labs_detect_healthcare_professional_consult_documents.johnsnowlabs_folder.en_classify_bert_sequence_vop_hcp_consult_pipeline",
        3: "john_snow_labs_extract_procedures_and_measurements_and_their_corresponding_cpt_codes.johnsnowlabs_folder.en_resolve_cpt_augmented",
        4: "john_snow_labs_extract_laboratory_observations_and_the_corresponding_loinc_codes.johnsnowlabs_folder.en_resolve_loinc_augmented",
        5: "john_snow_labs_guideline_summarizer_for_asthma___breast_cancer.johnsnowlabs_folder.en_summarize_clinical_guidelines_large_pipeline",
        6: "john_snow_labs_extract_clinical_findings_and_the_corresponding_icd10cm_codes.johnsnowlabs_folder.en_icd10cm_resolver_pipeline",
        7: "john_snow_labs_extract_clinical_findings_and_their_umls_codes.johnsnowlabs_folder.en_map_entity_umls_clinical_findings_resolver",
        8: "john_snow_labs_extract_neurologic_deficits_related_to_stroke_scale_nihss.johnsnowlabs_folder.en_med_ner_nihss_pipeline",
        9: "john_snow_labs_extract_clinical_findings_and_the_corresponding_icd_9_codes.johnsnowlabs_folder.en_resolve_icd9_pipeline",
        10: "john_snow_labs_extract_drugs_and_the_correspondingt_rxnorm_codes.johnsnowlabs_folder.en_map_entity_rxnorm_resolver_pipe",
        11: "john_snow_labs_extract_phenotypic_abnormalities_and_the_coresponding_hpo_codes_.johnsnowlabs_folder.en_resolve_HPO",
        12: "john_snow_labs_detect_drug_side_effect_narratives.johnsnowlabs_folder.en_classify_bert_sequence_vop_drug_side_effect_pipeline",
        13: "john_snow_labs_extract__drugs_and_substances_and_their_umls_codes.johnsnowlabs_folder.en_map_entity_umls_drug_resolver",
        14: "john_snow_labs_summarize_clinical_notes_in_laymen_terms_.johnsnowlabs_folder.en_summarize_clinical_laymen_onnx_pipeline",
        15: "john_snow_labs_extract_clinical_events_and_find_temporal_relations_era.johnsnowlabs_folder.en_explain_doc_era",
        16: "john_snow_labs_extract_findings_in_radiology_reports.johnsnowlabs_folder.en_explain_doc_clinical_radiology_pipeline",
        17: "john_snow_labs_detect_pathogen,_medical_condition_and_medicine.johnsnowlabs_folder.en_med_ner_pathogen_pipeline",
        18: "john_snow_labs_extract_patient_information_from_patient_narratives.johnsnowlabs_folder.en_med_ner_vop_langtest",
        19: "john_snow_labs_resolve_oncology_terminology_with_icd_o_taxonomy.johnsnowlabs_folder.en_resolve_icdo_augmented",
        20: "john_snow_labs_clinical_de_identification_for_portuguese_obfuscate.johnsnowlabs_folder.pt_deid_clinical",
        21: "john_snow_labs_clinical_de_identification_for_romanian_obfuscate.johnsnowlabs_folder.ro_deid_clinical",
        22: "john_snow_labs_extract_social_determinants_of_health.johnsnowlabs_folder.en_med_ner_sdoh_langtest_pipeline",
        23: "john_snow_labs_clinical_de_identification_for_french_obfuscate.johnsnowlabs_folder.fr_deid_obfuscated",
        24: "john_snow_labs_summarize_clinical_question_notes.johnsnowlabs_folder.en_summarize_clinical_questions_pipeline",
        25: "john_snow_labs_clinical_de_identification_for_spanish_obfuscate.johnsnowlabs_folder.es_deid_clinical",
        26: "john_snow_labs_clinical_de_identification_for_italian_obfuscate.johnsnowlabs_folder.it_deid_clinical",
        27: "john_snow_labs_clinical_de_identification_for_arabic_obfuscate.johnsnowlabs_folder.ar_deid_clinical",
        28: "john_snow_labs_clinical_de_identification_obfuscate.johnsnowlabs_folder.en_de_identify_clinical_pipeline",
        29: "john_snow_labs_clinical_de_identification_for_german_obfuscate.johnsnowlabs_folder.de_deid_clinical",
        30: "john_snow_labs_snomed_clinical_health_information_coder.johnsnowlabs_folder.en_resolve_snomed_findings",
        31: "john_snow_labs_extract_oncological_entities_and_relations.johnsnowlabs_folder.en_ner_oncology_pipeline",
        32: "john_snow_labs_clinical_de_identification_for_portuguese_mask.johnsnowlabs_folder.pt_deid_clinical",
        33: "john_snow_labs_clinical_text_summarization.johnsnowlabs_folder.en_summarize_clinical_jsl_augmented_pipeline",
        34: "john_snow_labs_extract_drugs_and_their_umls_codes.johnsnowlabs_folder.en_map_entity_umls_drug_resolver",
        35: "john_snow_labs_icd_10_cm_to_snomed_code_mapper.johnsnowlabs_folder.en_map_entity_icd10cm_to_snomed_pipe",
        36: "john_snow_labs_clinical_de_identification_for_romanian_mask.johnsnowlabs_folder.ro_deid_clinical",
        37: "john_snow_labs_snomed_to_icd_10_cm_code_mapper.johnsnowlabs_folder.en_map_entity_snomed_to_icd10cm_pipe",
        38: "john_snow_labs_clinical_de_identification_for_french_mask.johnsnowlabs_folder.fr_deid_obfuscated",
        39: "john_snow_labs_clinical_de_identification_for_spanish_mask.johnsnowlabs_folder.es_deid_clinical",
        40: "john_snow_labs_clinical_de_identification_for_arabic_mask.johnsnowlabs_folder.ar_deid_clinical",
        41: "john_snow_labs_clinical_de_identification_for_german_mask.johnsnowlabs_folder.de_deid_clinical",
        42: "john_snow_labs_clinical_de_identification_foritalian_mask.johnsnowlabs_folder.it_deid_clinical",
        43: "john_snow_labs_clinical_de_identification_mask.johnsnowlabs_folder.en_de_identify_clinical_pipeline",
        44: "john_snow_labs_summarize_pubmed_research.johnsnowlabs_folder.en_summarize_biomedical_pubmed_pipeline",
        45: "john_snow_labs_snomed_codes_to_icdo_codes_mapper.johnsnowlabs_folder.en_map_entity_snomed_to_icdo",
        46: "john_snow_labs_extract_adverse_drug_events_ade.johnsnowlabs_folder.en_explain_doc_clinical_ade",
        47: "john_snow_labs_extract_clinical_risk_factors.johnsnowlabs_folder.en_med_ner_risk_factors_pipeline",
        48: "john_snow_labs_rxnorm_to_ndc_code_converter.johnsnowlabs_folder.en_map_entity_rxnorm_to_ndc_pipe",
        49: "john_snow_labs_summarize_radiology_reports.johnsnowlabs_folder.en_summarize_radiology_pipeline",
        50: "john_snow_labs_extract_anatomical_structures.johnsnowlabs_folder.en_med_ner_anatom_pipeline",
        51: "john_snow_labs__icd_10_cm_to_umls_code_mapper.johnsnowlabs_folder.en_icd10cm_umls_mapping",
        52: "john_snow_labs_extract_living_species.johnsnowlabs_folder.en_med_ner_living_species_pipeline",
        53: "john_snow_labs_icd_10_to_icd_9_code_converter.johnsnowlabs_folder.en_icd10_icd9_mapping",
        54: "john_snow_labs_rxnorm_to_umls_code_mapper.johnsnowlabs_folder.en_rxnorm_umls_mapping",
        55: "john_snow_labs_detect_cancer_genetics.johnsnowlabs_folder.en_med_ner_bionlp_pipeline",
        56: "john_snow_labs_snomed_to_umls_code_mapper.johnsnowlabs_folder.en_snomed_umls_mapping",
        57: "john_snow_labs_rxnorm_to_mesh_code_mapper.johnsnowlabs_folder.en_rxnorm_mes_mapping",
        58: "john_snow_labs_mesh_to_umls_code_mapper.johnsnowlabs_folder.en_mesh_umls_mapping",
        59: "john_snow_labs_medication_coder.johnsnowlabs_folder.en_resolve_medication",
    },
    "CpuModelPath": {
        0: "john_snow_labs_extract_disease_and_syndrom_entities_and_their_umls_codes.johnsnowlabs_folder.en_map_entity_umls_disease_syndrome_resolver_cpu",
        1: "john_snow_labs_medical_question_answering_open_book_on_clinical_notes.johnsnowlabs_folder.en_answer_question_clinical_notes_onnx_pipeline_cpu",
        2: "john_snow_labs_detect_healthcare_professional_consult_documents.johnsnowlabs_folder.en_classify_bert_sequence_vop_hcp_consult_pipeline_cpu",
        3: "john_snow_labs_extract_procedures_and_measurements_and_their_corresponding_cpt_codes.johnsnowlabs_folder.en_resolve_cpt_augmented_cpu",
        4: "john_snow_labs_extract_laboratory_observations_and_the_corresponding_loinc_codes.johnsnowlabs_folder.en_resolve_loinc_augmented_cpu",
        5: "john_snow_labs_guideline_summarizer_for_asthma___breast_cancer.johnsnowlabs_folder.en_summarize_clinical_guidelines_large_pipeline_cpu",
        6: "john_snow_labs_extract_clinical_findings_and_the_corresponding_icd10cm_codes.johnsnowlabs_folder.en_icd10cm_resolver_pipeline_cpu",
        7: "john_snow_labs_extract_clinical_findings_and_their_umls_codes.johnsnowlabs_folder.en_map_entity_umls_clinical_findings_resolver_cpu",
        8: "john_snow_labs_extract_neurologic_deficits_related_to_stroke_scale_nihss.johnsnowlabs_folder.en_med_ner_nihss_pipeline_cpu",
        9: "john_snow_labs_extract_clinical_findings_and_the_corresponding_icd_9_codes.johnsnowlabs_folder.en_resolve_icd9_pipeline_cpu",
        10: "john_snow_labs_extract_drugs_and_the_correspondingt_rxnorm_codes.johnsnowlabs_folder.en_map_entity_rxnorm_resolver_pipe_cpu",
        11: "john_snow_labs_extract_phenotypic_abnormalities_and_the_coresponding_hpo_codes_.johnsnowlabs_folder.en_resolve_HPO_cpu",
        12: "john_snow_labs_detect_drug_side_effect_narratives.johnsnowlabs_folder.en_classify_bert_sequence_vop_drug_side_effect_pipeline_cpu",
        13: "john_snow_labs_extract__drugs_and_substances_and_their_umls_codes.johnsnowlabs_folder.en_map_entity_umls_drug_resolver_cpu",
        14: "john_snow_labs_summarize_clinical_notes_in_laymen_terms_.johnsnowlabs_folder.en_summarize_clinical_laymen_onnx_pipeline_cpu",
        15: "john_snow_labs_extract_clinical_events_and_find_temporal_relations_era.johnsnowlabs_folder.en_explain_doc_era_cpu",
        16: "john_snow_labs_extract_findings_in_radiology_reports.johnsnowlabs_folder.en_explain_doc_clinical_radiology_pipeline_cpu",
        17: "john_snow_labs_detect_pathogen,_medical_condition_and_medicine.johnsnowlabs_folder.en_med_ner_pathogen_pipeline_cpu",
        18: "john_snow_labs_extract_patient_information_from_patient_narratives.johnsnowlabs_folder.en_med_ner_vop_langtest_cpu",
        19: "john_snow_labs_resolve_oncology_terminology_with_icd_o_taxonomy.johnsnowlabs_folder.en_resolve_icdo_augmented_cpu",
        20: "john_snow_labs_clinical_de_identification_for_portuguese_obfuscate.johnsnowlabs_folder.pt_deid_clinical_cpu",
        21: "john_snow_labs_clinical_de_identification_for_romanian_obfuscate.johnsnowlabs_folder.ro_deid_clinical_cpu",
        22: "john_snow_labs_extract_social_determinants_of_health.johnsnowlabs_folder.en_med_ner_sdoh_langtest_pipeline_cpu",
        23: "john_snow_labs_clinical_de_identification_for_french_obfuscate.johnsnowlabs_folder.fr_deid_obfuscated_cpu",
        24: "john_snow_labs_summarize_clinical_question_notes.johnsnowlabs_folder.en_summarize_clinical_questions_pipeline_cpu",
        25: "john_snow_labs_clinical_de_identification_for_spanish_obfuscate.johnsnowlabs_folder.es_deid_clinical_cpu",
        26: "john_snow_labs_clinical_de_identification_for_italian_obfuscate.johnsnowlabs_folder.it_deid_clinical_cpu",
        27: "john_snow_labs_clinical_de_identification_for_arabic_obfuscate.johnsnowlabs_folder.ar_deid_clinical_cpu",
        28: "john_snow_labs_clinical_de_identification_obfuscate.johnsnowlabs_folder.en_de_identify_clinical_pipeline_cpu",
        29: "john_snow_labs_clinical_de_identification_for_german_obfuscate.johnsnowlabs_folder.de_deid_clinical_cpu",
        30: "john_snow_labs_snomed_clinical_health_information_coder.johnsnowlabs_folder.en_resolve_snomed_findings_cpu",
        31: "john_snow_labs_extract_oncological_entities_and_relations.johnsnowlabs_folder.en_ner_oncology_pipeline_cpu",
        32: "john_snow_labs_clinical_de_identification_for_portuguese_mask.johnsnowlabs_folder.pt_deid_clinical_cpu",
        33: "john_snow_labs_clinical_text_summarization.johnsnowlabs_folder.en_summarize_clinical_jsl_augmented_pipeline_cpu",
        34: "john_snow_labs_extract_drugs_and_their_umls_codes.johnsnowlabs_folder.en_map_entity_umls_drug_resolver_cpu",
        35: "john_snow_labs_icd_10_cm_to_snomed_code_mapper.johnsnowlabs_folder.en_map_entity_icd10cm_to_snomed_pipe_cpu",
        36: "john_snow_labs_clinical_de_identification_for_romanian_mask.johnsnowlabs_folder.ro_deid_clinical_cpu",
        37: "john_snow_labs_snomed_to_icd_10_cm_code_mapper.johnsnowlabs_folder.en_map_entity_snomed_to_icd10cm_pipe_cpu",
        38: "john_snow_labs_clinical_de_identification_for_french_mask.johnsnowlabs_folder.fr_deid_obfuscated_cpu",
        39: "john_snow_labs_clinical_de_identification_for_spanish_mask.johnsnowlabs_folder.es_deid_clinical_cpu",
        40: "john_snow_labs_clinical_de_identification_for_arabic_mask.johnsnowlabs_folder.ar_deid_clinical_cpu",
        41: "john_snow_labs_clinical_de_identification_for_german_mask.johnsnowlabs_folder.de_deid_clinical_cpu",
        42: "john_snow_labs_clinical_de_identification_foritalian_mask.johnsnowlabs_folder.it_deid_clinical_cpu",
        43: "john_snow_labs_clinical_de_identification_mask.johnsnowlabs_folder.en_de_identify_clinical_pipeline_cpu",
        44: "john_snow_labs_summarize_pubmed_research.johnsnowlabs_folder.en_summarize_biomedical_pubmed_pipeline_cpu",
        45: "john_snow_labs_snomed_codes_to_icdo_codes_mapper.johnsnowlabs_folder.en_map_entity_snomed_to_icdo_cpu",
        46: "john_snow_labs_extract_adverse_drug_events_ade.johnsnowlabs_folder.en_explain_doc_clinical_ade_cpu",
        47: "john_snow_labs_extract_clinical_risk_factors.johnsnowlabs_folder.en_med_ner_risk_factors_pipeline_cpu",
        48: "john_snow_labs_rxnorm_to_ndc_code_converter.johnsnowlabs_folder.en_map_entity_rxnorm_to_ndc_pipe_cpu",
        49: "john_snow_labs_summarize_radiology_reports.johnsnowlabs_folder.en_summarize_radiology_pipeline_cpu",
        50: "john_snow_labs_extract_anatomical_structures.johnsnowlabs_folder.en_med_ner_anatom_pipeline_cpu",
        51: "john_snow_labs__icd_10_cm_to_umls_code_mapper.johnsnowlabs_folder.en_icd10cm_umls_mapping_cpu",
        52: "john_snow_labs_extract_living_species.johnsnowlabs_folder.en_med_ner_living_species_pipeline_cpu",
        53: "john_snow_labs_icd_10_to_icd_9_code_converter.johnsnowlabs_folder.en_icd10_icd9_mapping_cpu",
        54: "john_snow_labs_rxnorm_to_umls_code_mapper.johnsnowlabs_folder.en_rxnorm_umls_mapping_cpu",
        55: "john_snow_labs_detect_cancer_genetics.johnsnowlabs_folder.en_med_ner_bionlp_pipeline_cpu",
        56: "john_snow_labs_snomed_to_umls_code_mapper.johnsnowlabs_folder.en_snomed_umls_mapping_cpu",
        57: "john_snow_labs_rxnorm_to_mesh_code_mapper.johnsnowlabs_folder.en_rxnorm_mes_mapping_cpu",
        58: "john_snow_labs_mesh_to_umls_code_mapper.johnsnowlabs_folder.en_mesh_umls_mapping_cpu",
        59: "john_snow_labs_medication_coder.johnsnowlabs_folder.en_resolve_medication_cpu",
    },
    "GpuModelPath": {
        0: "john_snow_labs_extract_disease_and_syndrom_entities_and_their_umls_codes.johnsnowlabs_folder.en_map_entity_umls_disease_syndrome_resolver_gpu",
        1: "john_snow_labs_medical_question_answering_open_book_on_clinical_notes.johnsnowlabs_folder.en_answer_question_clinical_notes_onnx_pipeline_gpu",
        2: "john_snow_labs_detect_healthcare_professional_consult_documents.johnsnowlabs_folder.en_classify_bert_sequence_vop_hcp_consult_pipeline_gpu",
        3: "john_snow_labs_extract_procedures_and_measurements_and_their_corresponding_cpt_codes.johnsnowlabs_folder.en_resolve_cpt_augmented_gpu",
        4: "john_snow_labs_extract_laboratory_observations_and_the_corresponding_loinc_codes.johnsnowlabs_folder.en_resolve_loinc_augmented_gpu",
        5: "john_snow_labs_guideline_summarizer_for_asthma___breast_cancer.johnsnowlabs_folder.en_summarize_clinical_guidelines_large_pipeline_gpu",
        6: "john_snow_labs_extract_clinical_findings_and_the_corresponding_icd10cm_codes.johnsnowlabs_folder.en_icd10cm_resolver_pipeline_gpu",
        7: "john_snow_labs_extract_clinical_findings_and_their_umls_codes.johnsnowlabs_folder.en_map_entity_umls_clinical_findings_resolver_gpu",
        8: "john_snow_labs_extract_neurologic_deficits_related_to_stroke_scale_nihss.johnsnowlabs_folder.en_med_ner_nihss_pipeline_gpu",
        9: "john_snow_labs_extract_clinical_findings_and_the_corresponding_icd_9_codes.johnsnowlabs_folder.en_resolve_icd9_pipeline_gpu",
        10: "john_snow_labs_extract_drugs_and_the_correspondingt_rxnorm_codes.johnsnowlabs_folder.en_map_entity_rxnorm_resolver_pipe_gpu",
        11: "john_snow_labs_extract_phenotypic_abnormalities_and_the_coresponding_hpo_codes_.johnsnowlabs_folder.en_resolve_HPO_gpu",
        12: "john_snow_labs_detect_drug_side_effect_narratives.johnsnowlabs_folder.en_classify_bert_sequence_vop_drug_side_effect_pipeline_gpu",
        13: "john_snow_labs_extract__drugs_and_substances_and_their_umls_codes.johnsnowlabs_folder.en_map_entity_umls_drug_resolver_gpu",
        14: "john_snow_labs_summarize_clinical_notes_in_laymen_terms_.johnsnowlabs_folder.en_summarize_clinical_laymen_onnx_pipeline_gpu",
        15: "john_snow_labs_extract_clinical_events_and_find_temporal_relations_era.johnsnowlabs_folder.en_explain_doc_era_gpu",
        16: "john_snow_labs_extract_findings_in_radiology_reports.johnsnowlabs_folder.en_explain_doc_clinical_radiology_pipeline_gpu",
        17: "john_snow_labs_detect_pathogen,_medical_condition_and_medicine.johnsnowlabs_folder.en_med_ner_pathogen_pipeline_gpu",
        18: "john_snow_labs_extract_patient_information_from_patient_narratives.johnsnowlabs_folder.en_med_ner_vop_langtest_gpu",
        19: "john_snow_labs_resolve_oncology_terminology_with_icd_o_taxonomy.johnsnowlabs_folder.en_resolve_icdo_augmented_gpu",
        20: "john_snow_labs_clinical_de_identification_for_portuguese_obfuscate.johnsnowlabs_folder.pt_deid_clinical_gpu",
        21: "john_snow_labs_clinical_de_identification_for_romanian_obfuscate.johnsnowlabs_folder.ro_deid_clinical_gpu",
        22: "john_snow_labs_extract_social_determinants_of_health.johnsnowlabs_folder.en_med_ner_sdoh_langtest_pipeline_gpu",
        23: "john_snow_labs_clinical_de_identification_for_french_obfuscate.johnsnowlabs_folder.fr_deid_obfuscated_gpu",
        24: "john_snow_labs_summarize_clinical_question_notes.johnsnowlabs_folder.en_summarize_clinical_questions_pipeline_gpu",
        25: "john_snow_labs_clinical_de_identification_for_spanish_obfuscate.johnsnowlabs_folder.es_deid_clinical_gpu",
        26: "john_snow_labs_clinical_de_identification_for_italian_obfuscate.johnsnowlabs_folder.it_deid_clinical_gpu",
        27: "john_snow_labs_clinical_de_identification_for_arabic_obfuscate.johnsnowlabs_folder.ar_deid_clinical_gpu",
        28: "john_snow_labs_clinical_de_identification_obfuscate.johnsnowlabs_folder.en_de_identify_clinical_pipeline_gpu",
        29: "john_snow_labs_clinical_de_identification_for_german_obfuscate.johnsnowlabs_folder.de_deid_clinical_gpu",
        30: "john_snow_labs_snomed_clinical_health_information_coder.johnsnowlabs_folder.en_resolve_snomed_findings_gpu",
        31: "john_snow_labs_extract_oncological_entities_and_relations.johnsnowlabs_folder.en_ner_oncology_pipeline_gpu",
        32: "john_snow_labs_clinical_de_identification_for_portuguese_mask.johnsnowlabs_folder.pt_deid_clinical_gpu",
        33: "john_snow_labs_clinical_text_summarization.johnsnowlabs_folder.en_summarize_clinical_jsl_augmented_pipeline_gpu",
        34: "john_snow_labs_extract_drugs_and_their_umls_codes.johnsnowlabs_folder.en_map_entity_umls_drug_resolver_gpu",
        35: "john_snow_labs_icd_10_cm_to_snomed_code_mapper.johnsnowlabs_folder.en_map_entity_icd10cm_to_snomed_pipe_gpu",
        36: "john_snow_labs_clinical_de_identification_for_romanian_mask.johnsnowlabs_folder.ro_deid_clinical_gpu",
        37: "john_snow_labs_snomed_to_icd_10_cm_code_mapper.johnsnowlabs_folder.en_map_entity_snomed_to_icd10cm_pipe_gpu",
        38: "john_snow_labs_clinical_de_identification_for_french_mask.johnsnowlabs_folder.fr_deid_obfuscated_gpu",
        39: "john_snow_labs_clinical_de_identification_for_spanish_mask.johnsnowlabs_folder.es_deid_clinical_gpu",
        40: "john_snow_labs_clinical_de_identification_for_arabic_mask.johnsnowlabs_folder.ar_deid_clinical_gpu",
        41: "john_snow_labs_clinical_de_identification_for_german_mask.johnsnowlabs_folder.de_deid_clinical_gpu",
        42: "john_snow_labs_clinical_de_identification_foritalian_mask.johnsnowlabs_folder.it_deid_clinical_gpu",
        43: "john_snow_labs_clinical_de_identification_mask.johnsnowlabs_folder.en_de_identify_clinical_pipeline_gpu",
        44: "john_snow_labs_summarize_pubmed_research.johnsnowlabs_folder.en_summarize_biomedical_pubmed_pipeline_gpu",
        45: "john_snow_labs_snomed_codes_to_icdo_codes_mapper.johnsnowlabs_folder.en_map_entity_snomed_to_icdo_gpu",
        46: "john_snow_labs_extract_adverse_drug_events_ade.johnsnowlabs_folder.en_explain_doc_clinical_ade_gpu",
        47: "john_snow_labs_extract_clinical_risk_factors.johnsnowlabs_folder.en_med_ner_risk_factors_pipeline_gpu",
        48: "john_snow_labs_rxnorm_to_ndc_code_converter.johnsnowlabs_folder.en_map_entity_rxnorm_to_ndc_pipe_gpu",
        49: "john_snow_labs_summarize_radiology_reports.johnsnowlabs_folder.en_summarize_radiology_pipeline_gpu",
        50: "john_snow_labs_extract_anatomical_structures.johnsnowlabs_folder.en_med_ner_anatom_pipeline_gpu",
        51: "john_snow_labs__icd_10_cm_to_umls_code_mapper.johnsnowlabs_folder.en_icd10cm_umls_mapping_gpu",
        52: "john_snow_labs_extract_living_species.johnsnowlabs_folder.en_med_ner_living_species_pipeline_gpu",
        53: "john_snow_labs_icd_10_to_icd_9_code_converter.johnsnowlabs_folder.en_icd10_icd9_mapping_gpu",
        54: "john_snow_labs_rxnorm_to_umls_code_mapper.johnsnowlabs_folder.en_rxnorm_umls_mapping_gpu",
        55: "john_snow_labs_detect_cancer_genetics.johnsnowlabs_folder.en_med_ner_bionlp_pipeline_gpu",
        56: "john_snow_labs_snomed_to_umls_code_mapper.johnsnowlabs_folder.en_snomed_umls_mapping_gpu",
        57: "john_snow_labs_rxnorm_to_mesh_code_mapper.johnsnowlabs_folder.en_rxnorm_mes_mapping_gpu",
        58: "john_snow_labs_mesh_to_umls_code_mapper.johnsnowlabs_folder.en_mesh_umls_mapping_gpu",
        59: "john_snow_labs_medication_coder.johnsnowlabs_folder.en_resolve_medication_gpu",
    },
    "ListingId": {
        0: "cf968e18-d8d8-4b9f-b79a-fc4e4a3337a7",
        1: "35e98245-c1bd-4a35-be0b-6daf0e9a3825",
        2: "f29c9e93-8f2d-4969-b472-f3524bdfd883",
        3: "e1a5be5d-b799-4bd1-a664-c31b9c47225f",
        4: "a299884a-7a95-4ddf-96e0-b8594c4290d3",
        5: "153b223a-d73f-479f-a51c-8905434b545d",
        6: "80b9ec4d-c7b8-401c-b177-aa388259f422",
        7: "29d9158d-33ed-4805-ad4b-92ff210e808b",
        8: "7afe6ca0-ad66-489b-b2d0-b31b0644d053",
        9: "c2469843-c104-4201-9db5-ba1542823448",
        10: "2b8709b8-4a42-406b-bd93-43172eae07b9",
        11: "d07d7654-d483-4f1d-bb26-13b02197b87f",
        12: "48daa468-2417-437a-b59d-0a06a8935d99",
        13: "10de7650-8e88-461e-bea4-6c38bb3f0d00",
        14: "3ec7ae21-ef22-4ae3-ac52-70a0ef4dedc2",
        15: "2a078943-c56d-48b1-a99d-3addb38d688f",
        16: "a516cbd4-107d-4194-ab02-74095c155f34",
        17: "f52c1b80-794f-457f-bb94-51c5df3ee4be",
        18: "685dab5c-03cb-4545-9a71-e08ae72946e6",
        19: "074bbfa7-20ad-4444-8e0a-bc05ff07d6ea",
        20: "8dd5abe1-4df8-41b5-a251-dcf3b161f5c3",
        21: "68c7064e-c1dc-459f-971b-e759bb80810d",
        22: "c23fe435-9461-4d0e-a829-d64f6fecb659",
        23: "eb2042f5-8a50-459c-8884-e11f9573c618",
        24: "251eeb55-2ff6-4e7f-ab92-dbbbabe5c2a4",
        25: "bb9e02a3-3926-4125-bfdf-49cdef5d1ca7",
        26: "ac413121-3018-4a1f-95c1-fadbbf321708",
        27: "b3bac611-ed88-4391-b013-08de4e32a503",
        28: "facfaf55-00f6-496c-a8db-a395631130ec",
        29: "37b22ea9-caf2-429e-ac3c-8b1adb0324cc",
        30: "de82227b-b6d2-4243-857f-071c4b860e8b",
        31: "00affefe-d268-4bd2-9fa1-8d3a07199be0",
        32: "a5111c18-1c60-4c02-a25a-fa709e819ecd",
        33: "88bf2ba0-fb95-44f8-801d-325a720b6f03",
        34: "bfb569e4-69a2-4f4b-8d6e-e306982e4a95",
        35: "1edf9844-470b-4e3a-a157-3ed8c5af89a9",
        36: "8a7ef1cd-c307-4bc7-94c7-4b812a64d3c4",
        37: "5e6f0af1-bcc7-4aa6-a1de-21ca58638fce",
        38: "c600aad0-84c6-4f3d-ae92-5541d3cad171",
        39: "c0456a4c-beeb-4258-9b4a-12e0964e33e5",
        40: "7f5d667a-82a9-48b8-b559-408c589259cd",
        41: "833ccefd-89a0-4e74-8b1d-ddb32181693b",
        42: "51ec7304-2cce-4c60-830e-9fe735ac2a89",
        43: "40f9b4db-ba84-4af1-aba6-57abfba24676",
        44: "9956314c-f7a4-42e0-8081-a7f933ea0c8c",
        45: "e3d2930b-b3bc-4f26-9d35-e81fa9fdd161",
        46: "64d6608b-8341-4b14-8edd-c1a1b31823a6",
        47: "4d973f25-f457-4af7-8ea7-7c3fddaf9493",
        48: "bf4cd2a7-55b5-40fa-b010-c89f54b29ab8",
        49: "0fa941ad-cf3d-4b03-8e46-854e6299afe8",
        50: "7487be7b-0f6d-4aaf-82ef-ea2b1833685a",
        51: "0ee92a5c-35f1-40c9-a7b3-0282e67d9bd1",
        52: "7418db61-8ff0-49db-ae87-756fc17382fc",
        53: "5c645046-e195-4164-a5f5-d3015a7f7647",
        54: "379d172e-cc3f-4c17-ae25-6c83f91e2e6a",
        55: "0a5aebb4-6f73-4af6-96d4-f8d2acfce25d",
        56: "83306cbb-ac15-46e4-86a1-43036dd0c1ec",
        57: "b1a7c3ca-3d76-4434-a979-7ed9ad720530",
        58: "5b4cc372-b9b5-4632-9090-89ddfbef7fe5",
        59: "c0511f92-316e-4106-b09c-b3f55fcca24f",
    },
    "DropDownId": {
        0: "42. Extract Disease and Syndrom entities and their UMLS Codes",
        1: "23. Medical Question Answering (Open-Book on Clinical Notes)",
        2: "29. Detect Healthcare Professional Consult documents",
        3: "48. Extract procedures and measurements and their corresponding CPT codes",
        4: "60. Extract Laboratory Observations and the corresponding LOINC codes",
        5: "18. Guideline Summarizer for Asthma & Breast Cancer",
        6: "40. Extract Clinical Findings and the corresponding ICD10CM codes",
        7: "45. Extract Clinical Findings and their UMLS Codes",
        8: "32. Extract neurologic deficits related to Stroke Scale (NIHSS)",
        9: "44. Extract Clinical Findings and the corresponding ICD 9 codes",
        10: "39. Extract Drugs and the correspondingt RXNORM codes",
        11: "47. Extract phenotypic abnormalities and the coresponding HPO codes ",
        12: "30. Detect Drug Side Effect Narratives",
        13: "38. Extract  Drugs and Substances and their UMLS Codes",
        14: "19. Summarize Clinical Notes in Laymen Terms ",
        15: "24. Extract clinical events and find temporal relations",
        16: "25. Extract findings in radiology reports",
        17: "35. Detect Pathogen, Medical Condition and Medicine",
        18: "28. Extract patient information from patient narratives",
        19: "52. Resolve Oncology terminology with ICD-O Taxonomy",
        20: "12. Clinical De-identification for Portuguese (Obfuscate)",
        21: "16. Clinical De-identification for Romanian (Obfuscate)",
        22: "31. Extract Social Determinants of Health",
        23: "10. Clinical De-identification for French (Obfuscate)",
        24: "20. Summarize Clinical Question Notes",
        25: "6. Clinical De-identification for Spanish (Obfuscate)",
        26: "8. Clinical De-identification for Italian (Obfuscate)",
        27: "14. Clinical De-identification for Arabic (Obfuscate)",
        28: "2. Clinical De-identification (Obfuscate)",
        29: "4. Clinical De-identification for German (Obfuscate)",
        30: "56. SNOMED Clinical Health Information Coder",
        31: "27. Extract oncological entities and relations",
        32: "11. Clinical De-identification for Portuguese (Mask)",
        33: "22. Clinical Text Summarization",
        34: "46. Extract Drugs and their UMLS Codes",
        35: "49. ICD-10-CM to SNOMED Code Mapper",
        36: "15. Clinical De-identification for Romanian (Mask)",
        37: "58. SNOMED to ICD-10-CM Code Mapper",
        38: "9. Clinical De-identification for French (Mask)",
        39: "5. Clinical De-identification for Spanish (Mask)",
        40: "13. Clinical De-identification for Arabic (Mask)",
        41: "3. Clinical De-identification for German (Mask)",
        42: "7. Clinical De-identification forItalian (Mask)",
        43: "1. Clinical De-identification (Mask)",
        44: "21. Summarize PubMed Research",
        45: "57. SNOMED Codes to ICDO Codes Mapper",
        46: "26. Extract Adverse Drug Events (ADE)",
        47: "33. Extract clinical risk factors",
        48: "54. RxNorm to NDC Code Converter",
        49: "17. Summarize Radiology Reports",
        50: "37. Extract Anatomical Structures",
        51: "43. ICD-10-CM to UMLS Code Mapper",
        52: "36. Extract Living Species",
        53: "50. ICD-10 to ICD-9 Code Converter",
        54: "55. RxNorm to UMLS Code Mapper",
        55: "34. Detect Cancer Genetics",
        56: "59. SNOMED to UMLS Code Mapper",
        57: "53. RxNorm to MeSH Code Mapper",
        58: "51. MeSH to UMLS Code Mapper",
        59: "41. Medication Coder",
    },
    "Id": {
        0: 42.0,
        1: 23.0,
        2: 29.0,
        3: 48.0,
        4: 60.0,
        5: 18.0,
        6: 40.0,
        7: 45.0,
        8: 32.0,
        9: 44.0,
        10: 39.0,
        11: 47.0,
        12: 30.0,
        13: 38.0,
        14: 19.0,
        15: 24.0,
        16: 25.0,
        17: 35.0,
        18: 28.0,
        19: 52.0,
        20: 12.0,
        21: 16.0,
        22: 31.0,
        23: 10.0,
        24: 20.0,
        25: 6.0,
        26: 8.0,
        27: 14.0,
        28: 2.0,
        29: 4.0,
        30: 56.0,
        31: 27.0,
        32: 11.0,
        33: 22.0,
        34: 46.0,
        35: 49.0,
        36: 15.0,
        37: 58.0,
        38: 9.0,
        39: 5.0,
        40: 13.0,
        41: 3.0,
        42: 7.0,
        43: 1.0,
        44: 21.0,
        45: 57.0,
        46: 26.0,
        47: 33.0,
        48: 54.0,
        49: 17.0,
        50: 37.0,
        51: 43.0,
        52: 36.0,
        53: 50.0,
        54: 55.0,
        55: 34.0,
        56: 59.0,
        57: 53.0,
        58: 51.0,
        59: 41.0,
    },
    "Title_d": {
        0: "[Extract Disease and Syndrom entities and their UMLS Codes](./marketplace/consumer/listings/cf968e18-d8d8-4b9f-b79a-fc4e4a3337a7)",
        1: "[Medical Question Answering (Open-Book on Clinical Notes)](./marketplace/consumer/listings/35e98245-c1bd-4a35-be0b-6daf0e9a3825)",
        2: "[Detect Healthcare Professional Consult documents](./marketplace/consumer/listings/f29c9e93-8f2d-4969-b472-f3524bdfd883)",
        3: "[Extract procedures and measurements and their corresponding CPT codes](./marketplace/consumer/listings/e1a5be5d-b799-4bd1-a664-c31b9c47225f)",
        4: "[Extract Laboratory Observations and the corresponding LOINC codes](./marketplace/consumer/listings/a299884a-7a95-4ddf-96e0-b8594c4290d3)",
        5: "[Guideline Summarizer for Asthma & Breast Cancer](./marketplace/consumer/listings/153b223a-d73f-479f-a51c-8905434b545d)",
        6: "[Extract Clinical Findings and the corresponding ICD10CM codes](./marketplace/consumer/listings/80b9ec4d-c7b8-401c-b177-aa388259f422)",
        7: "[Extract Clinical Findings and their UMLS Codes](./marketplace/consumer/listings/29d9158d-33ed-4805-ad4b-92ff210e808b)",
        8: "[Extract neurologic deficits related to Stroke Scale (NIHSS)](./marketplace/consumer/listings/7afe6ca0-ad66-489b-b2d0-b31b0644d053)",
        9: "[Extract Clinical Findings and the corresponding ICD 9 codes](./marketplace/consumer/listings/c2469843-c104-4201-9db5-ba1542823448)",
        10: "[Extract Drugs and the correspondingt RXNORM codes](./marketplace/consumer/listings/2b8709b8-4a42-406b-bd93-43172eae07b9)",
        11: "[Extract phenotypic abnormalities and the coresponding HPO codes ](./marketplace/consumer/listings/d07d7654-d483-4f1d-bb26-13b02197b87f)",
        12: "[Detect Drug Side Effect Narratives](./marketplace/consumer/listings/48daa468-2417-437a-b59d-0a06a8935d99)",
        13: "[Extract  Drugs and Substances and their UMLS Codes](./marketplace/consumer/listings/10de7650-8e88-461e-bea4-6c38bb3f0d00)",
        14: "[Summarize Clinical Notes in Laymen Terms ](./marketplace/consumer/listings/3ec7ae21-ef22-4ae3-ac52-70a0ef4dedc2)",
        15: "[Extract clinical events and find temporal relations (ERA)](./marketplace/consumer/listings/2a078943-c56d-48b1-a99d-3addb38d688f)",
        16: "[Extract findings in radiology reports](./marketplace/consumer/listings/a516cbd4-107d-4194-ab02-74095c155f34)",
        17: "[Detect Pathogen, Medical Condition and Medicine](./marketplace/consumer/listings/f52c1b80-794f-457f-bb94-51c5df3ee4be)",
        18: "[Extract patient information from patient narratives](./marketplace/consumer/listings/685dab5c-03cb-4545-9a71-e08ae72946e6)",
        19: "[Resolve Oncology terminology with ICD-O Taxonomy](./marketplace/consumer/listings/074bbfa7-20ad-4444-8e0a-bc05ff07d6ea)",
        20: "[Clinical De-identification for Portuguese (Obfuscate)](./marketplace/consumer/listings/8dd5abe1-4df8-41b5-a251-dcf3b161f5c3)",
        21: "[Clinical De-identification for Romanian (Obfuscate)](./marketplace/consumer/listings/68c7064e-c1dc-459f-971b-e759bb80810d)",
        22: "[Extract Social Determinants of Health](./marketplace/consumer/listings/c23fe435-9461-4d0e-a829-d64f6fecb659)",
        23: "[Clinical De-identification for French (Obfuscate)](./marketplace/consumer/listings/eb2042f5-8a50-459c-8884-e11f9573c618)",
        24: "[Summarize Clinical Question Notes](./marketplace/consumer/listings/251eeb55-2ff6-4e7f-ab92-dbbbabe5c2a4)",
        25: "[Clinical De-identification for Spanish (Obfuscate)](./marketplace/consumer/listings/bb9e02a3-3926-4125-bfdf-49cdef5d1ca7)",
        26: "[Clinical De-identification for Italian (Obfuscate)](./marketplace/consumer/listings/ac413121-3018-4a1f-95c1-fadbbf321708)",
        27: "[Clinical De-identification for Arabic (Obfuscate)](./marketplace/consumer/listings/b3bac611-ed88-4391-b013-08de4e32a503)",
        28: "[Clinical De-identification (Obfuscate)](./marketplace/consumer/listings/facfaf55-00f6-496c-a8db-a395631130ec)",
        29: "[Clinical De-identification for German (Obfuscate)](./marketplace/consumer/listings/37b22ea9-caf2-429e-ac3c-8b1adb0324cc)",
        30: "[SNOMED Clinical Health Information Coder](./marketplace/consumer/listings/de82227b-b6d2-4243-857f-071c4b860e8b)",
        31: "[Extract oncological entities and relations](./marketplace/consumer/listings/00affefe-d268-4bd2-9fa1-8d3a07199be0)",
        32: "[Clinical De-identification for Portuguese (Mask)](./marketplace/consumer/listings/a5111c18-1c60-4c02-a25a-fa709e819ecd)",
        33: "[Clinical Text Summarization](./marketplace/consumer/listings/88bf2ba0-fb95-44f8-801d-325a720b6f03)",
        34: "[Extract Drugs and their UMLS Codes](./marketplace/consumer/listings/bfb569e4-69a2-4f4b-8d6e-e306982e4a95)",
        35: "[ICD-10-CM to SNOMED Code Mapper](./marketplace/consumer/listings/1edf9844-470b-4e3a-a157-3ed8c5af89a9)",
        36: "[Clinical De-identification for Romanian (Mask)](./marketplace/consumer/listings/8a7ef1cd-c307-4bc7-94c7-4b812a64d3c4)",
        37: "[SNOMED to ICD-10-CM Code Mapper](./marketplace/consumer/listings/5e6f0af1-bcc7-4aa6-a1de-21ca58638fce)",
        38: "[Clinical De-identification for French (Mask)](./marketplace/consumer/listings/c600aad0-84c6-4f3d-ae92-5541d3cad171)",
        39: "[Clinical De-identification for Spanish (Mask)](./marketplace/consumer/listings/c0456a4c-beeb-4258-9b4a-12e0964e33e5)",
        40: "[Clinical De-identification for Arabic (Mask)](./marketplace/consumer/listings/7f5d667a-82a9-48b8-b559-408c589259cd)",
        41: "[Clinical De-identification for German (Mask)](./marketplace/consumer/listings/833ccefd-89a0-4e74-8b1d-ddb32181693b)",
        42: "[Clinical De-identification forItalian (Mask)](./marketplace/consumer/listings/51ec7304-2cce-4c60-830e-9fe735ac2a89)",
        43: "[Clinical De-identification (Mask)](./marketplace/consumer/listings/40f9b4db-ba84-4af1-aba6-57abfba24676)",
        44: "[Summarize PubMed Research](./marketplace/consumer/listings/9956314c-f7a4-42e0-8081-a7f933ea0c8c)",
        45: "[SNOMED Codes to ICDO Codes Mapper](./marketplace/consumer/listings/e3d2930b-b3bc-4f26-9d35-e81fa9fdd161)",
        46: "[Extract Adverse Drug Events (ADE)](./marketplace/consumer/listings/64d6608b-8341-4b14-8edd-c1a1b31823a6)",
        47: "[Extract clinical risk factors](./marketplace/consumer/listings/4d973f25-f457-4af7-8ea7-7c3fddaf9493)",
        48: "[RxNorm to NDC Code Converter](./marketplace/consumer/listings/bf4cd2a7-55b5-40fa-b010-c89f54b29ab8)",
        49: "[Summarize Radiology Reports](./marketplace/consumer/listings/0fa941ad-cf3d-4b03-8e46-854e6299afe8)",
        50: "[Extract Anatomical Structures](./marketplace/consumer/listings/7487be7b-0f6d-4aaf-82ef-ea2b1833685a)",
        51: "[ ICD-10-CM to UMLS Code Mapper](./marketplace/consumer/listings/0ee92a5c-35f1-40c9-a7b3-0282e67d9bd1)",
        52: "[Extract Living Species](./marketplace/consumer/listings/7418db61-8ff0-49db-ae87-756fc17382fc)",
        53: "[ICD-10 to ICD-9 Code Converter](./marketplace/consumer/listings/5c645046-e195-4164-a5f5-d3015a7f7647)",
        54: "[RxNorm to UMLS Code Mapper](./marketplace/consumer/listings/379d172e-cc3f-4c17-ae25-6c83f91e2e6a)",
        55: "[Detect Cancer Genetics](./marketplace/consumer/listings/0a5aebb4-6f73-4af6-96d4-f8d2acfce25d)",
        56: "[SNOMED to UMLS Code Mapper](./marketplace/consumer/listings/83306cbb-ac15-46e4-86a1-43036dd0c1ec)",
        57: "[RxNorm to MeSH Code Mapper](./marketplace/consumer/listings/b1a7c3ca-3d76-4434-a979-7ed9ad720530)",
        58: "[MeSH to UMLS Code Mapper](./marketplace/consumer/listings/5b4cc372-b9b5-4632-9090-89ddfbef7fe5)",
        59: "[Medication Coder](./marketplace/consumer/listings/c0511f92-316e-4106-b09c-b3f55fcca24f)",
    },
}


import pandas as pd

models_df = pd.DataFrame(models).reset_index()
